@@ -22,11 +22,14 @@
 
 # Import
 import logging
+
 import os
 import codecs
+
 from pythonsol.SolBase import SolBase
 
-SolBase.loggingInit()
+
+SolBase.logging_init()
 logger = logging.getLogger("FileUtility")
 
 
@@ -45,76 +48,76 @@ class FileUtility(object):
         """
 
     @staticmethod
-    def isPathExist(pathName):
+    def is_path_exist(path_name):
         """
         Check if a path (file or dir) name exist.
-        :param pathName: Path name.
+        :param path_name: Path name.
         :return: Return true (exist), false (do not exist, or invalid file name)
         """
 
-        #  Check
-        if pathName is None:
-            logger.error("isPathExist : fileName is None")
+        # Check
+        if path_name is None:
+            logger.error("is_path_exist : file_name is None")
             return False
-        elif not isinstance(pathName, str):
-            logger.error("isPathExist : pathName not a str, className=%s", SolBase.getClassName(pathName))
+        elif not isinstance(path_name, str):
+            logger.error("is_path_exist : path_name not a str, className=%s", SolBase.get_classname(path_name))
             return False
 
         # Go
-        return os.path.exists(pathName)
+        return os.path.exists(path_name)
 
     @staticmethod
-    def isFileExist(fileName):
+    def is_file_exist(file_name):
         """
         Check if file name exist.
-        :param fileName: File name.
+        :param file_name: File name.
         :return: Return true (exist), false (do not exist, or invalid file name)
         """
 
-        #  Check
-        if fileName is None:
-            logger.error("isFileExist : fileName is None")
+        # Check
+        if file_name is None:
+            logger.error("is_file_exist : file_name is None")
             return False
-        elif not isinstance(fileName, str):
-            logger.error("isFileExist : fileName not a str, className=%s", SolBase.getClassName(fileName))
+        elif not isinstance(file_name, str):
+            logger.error("is_file_exist : file_name not a str, className=%s", SolBase.get_classname(file_name))
             return False
 
         # Go
-        return os.path.isfile(fileName)
+        return os.path.isfile(file_name)
 
     @staticmethod
-    def isDirExist(dirName):
+    def is_dir_exist(dir_name):
         """
         Check if dir name exist.
-        :param dirName: Directory name.
+        :param dir_name: Directory name.
         :return: Return true (exist), false (do not exist, or invalid file name)
         """
 
-        #  Check
-        if dirName is None:
-            logger.error("isDirExist : fileName is None")
+        # Check
+        if dir_name is None:
+            logger.error("is_dir_exist : file_name is None")
             return False
-        elif not isinstance(dirName, str):
-            logger.error("isDirExist : fileName not a str, className=%s", SolBase.getClassName(dirName))
+        elif not isinstance(dir_name, str):
+            logger.error("is_dir_exist : file_name not a str, className=%s", SolBase.get_classname(dir_name))
             return False
 
         # Go
-        return os.path.isdir(dirName)
+        return os.path.isdir(dir_name)
 
     @staticmethod
-    def getFileSize(fileName):
+    def get_file_size(file_name):
         """
         Return a file size in bytes.
-        :param fileName: File name.
+        :param file_name: File name.
         :return: An integer, gt-eq 0 if file exist, lt 0 if error.
         """
-        if not FileUtility.isFileExist(fileName):
+        if not FileUtility.is_file_exist(file_name):
             return -1
         else:
-            return os.path.getsize(fileName)
+            return os.path.getsize(file_name)
 
     @classmethod
-    def getCurrentDir(cls):
+    def get_current_dir(cls):
         """
         Return the current directory.
         :return: A String
@@ -123,48 +126,48 @@ class FileUtility(object):
         return os.getcwd()
 
     @classmethod
-    def splitPath(cls, path):
+    def split_path(cls, path):
         """
         Split path, returning a list.
         :param path: A path.
         :return: A list of path component.
         """
-        return path.split(SolBase.getPathSeparator())
+        return path.split(SolBase.get_pathseparator())
 
     @staticmethod
-    def fileToByteBuffer(fileName):
+    def file_to_byte_buffer(file_name):
         """
         Load a file toward a binary buffer.
-        :param fileName: File name.
+        :param file_name: File name.
         :return: Return the binary buffer or None in case of error.
         """
 
         # Check
-        if not FileUtility.isFileExist(fileName):
-            logger.error("fileToByteBuffer : fileName not exist, fileName=%s", fileName)
+        if not FileUtility.is_file_exist(file_name):
+            logger.error("file_to_byte_buffer : file_name not exist, file_name=%s", file_name)
             return None
 
         # Go
         rd = None
         try:
             # Open (binary : open return a io.BufferedReader)
-            rd = open(fileName, "rb")
+            rd = open(file_name, "rb")
 
             # Preallocate buffer (faster)
-            binbuf = bytearray(FileUtility.getFileSize(fileName))
+            binbuf = bytearray(FileUtility.get_file_size(file_name))
 
             # Read everything
-            #noinspection PyArgumentList
+            # noinspection PyArgumentList
             rd.readinto(binbuf)
 
             # Return
             return binbuf
         except IOError as e:
             # Exception...
-            logger.error("fileToByteBuffer : IOError, ex=%s", SolBase.exToStr(e))
+            logger.error("file_to_byte_buffer : IOError, ex=%s", SolBase.extostr(e))
             return None
         except Exception as e:
-            logger.error("fileToByteBuffer : Exception, ex=%s", SolBase.exToStr(e))
+            logger.error("file_to_byte_buffer : Exception, ex=%s", SolBase.extostr(e))
             return None
         finally:
             # Close if not None...
@@ -172,34 +175,34 @@ class FileUtility(object):
                 rd.close()
 
     @staticmethod
-    def fileToTextBuffer(fileName, encoding):
+    def file_to_textbuffer(file_name, encoding):
         """
         Load a file toward a text buffer (UTF-8), using the specify encoding while reading.
         CAUTION : This will read the whole file IN MEMORY.
-        :param fileName: File name.
+        :param file_name: File name.
         :param encoding: Encoding to user.
         :return: A text buffer or None in case of error.
         """
 
         # Check
-        if not FileUtility.isFileExist(fileName):
-            logger.error("fileToTextBuffer : fileName not exist, fileName=%s", fileName)
+        if not FileUtility.is_file_exist(file_name):
+            logger.error("file_to_textbuffer : file_name not exist, file_name=%s", file_name)
             return None
 
         # Go
         rd = None
         try:
             # Open (text : open return a io.BufferedReader)
-            rd = codecs.open(fileName, "rt", encoding, "strict", -1)
+            rd = codecs.open(file_name, "rt", encoding, "strict", -1)
 
             # Read everything
             return rd.read()
         except IOError as e:
             # Exception...
-            logger.error("fileToByteBuffer : IOError, ex=%s", SolBase.exToStr(e))
+            logger.error("file_to_byte_buffer : IOError, ex=%s", SolBase.extostr(e))
             return None
         except Exception as e:
-            logger.error("fileToByteBuffer : Exception, ex=%s", SolBase.exToStr(e))
+            logger.error("file_to_byte_buffer : Exception, ex=%s", SolBase.extostr(e))
             return None
         finally:
             # Close if not None...
@@ -207,12 +210,12 @@ class FileUtility(object):
                 rd.close()
 
     @staticmethod
-    def appendBinaryToFile(fileName, binaryBuffer):
+    def append_binary_tofile(file_name, bin_buf):
         """
         Write to the specified filename, the provided binary buffer.
         Create the file if required.
-        :param fileName:  File name.
-        :param binaryBuffer: Binary buffer to write.
+        :param file_name:  File name.
+        :param bin_buf: Binary buffer to write.
         :return: The number of bytes written or lt 0 if error.
         """
 
@@ -220,16 +223,16 @@ class FileUtility(object):
         rd = None
         try:
             # Open (text : open return a io.BufferedReader)
-            rd = open(fileName, "ab+")
+            rd = open(file_name, "ab+")
 
             # Read everything
-            return rd.write(binaryBuffer)
+            return rd.write(bin_buf)
         except IOError as e:
             # Exception...
-            logger.error("appendBinaryToFile : IOError, ex=%s", SolBase.exToStr(e))
+            logger.error("append_binary_tofile : IOError, ex=%s", SolBase.extostr(e))
             return -1
         except Exception as e:
-            logger.error("appendBinaryToFile : Exception, ex=%s", SolBase.exToStr(e))
+            logger.error("append_binary_tofile : Exception, ex=%s", SolBase.extostr(e))
             return -1
         finally:
             # Close if not None...
@@ -237,12 +240,12 @@ class FileUtility(object):
                 rd.close()
 
     @staticmethod
-    def appendTextToFile(fileName, textBuffer, encoding, overwrite=False):
+    def append_text_tofile(file_name, text_buffer, encoding, overwrite=False):
         """
         Write to the specified filename, the provided binary buffer
         Create the file if required.
-        :param fileName:  File name.
-        :param textBuffer: Text buffer to write.
+        :param file_name:  File name.
+        :param text_buffer: Text buffer to write.
         :param encoding: The encoding to user.
         :param overwrite: If true, file is overwritten.
         :return: The number of bytes written or lt 0 if error.
@@ -253,19 +256,19 @@ class FileUtility(object):
         try:
             # Open (text : open return a io.BufferedReader)
             if not overwrite:
-                rd = codecs.open(fileName, "at+", encoding, "strict", -1)
+                rd = codecs.open(file_name, "at+", encoding, "strict", -1)
             else:
-                rd = codecs.open(fileName, "wt", encoding, "strict", -1)
+                rd = codecs.open(file_name, "wt", encoding, "strict", -1)
 
             # Read everything
             # CAUTION : 2.7 return None :(
-            return rd.write(textBuffer)
+            return rd.write(text_buffer)
         except IOError as e:
             # Exception...
-            logger.error("appendTextToFile : IOError, ex=%s", SolBase.exToStr(e))
+            logger.error("append_text_tofile : IOError, ex=%s", SolBase.extostr(e))
             return -1
         except Exception as e:
-            logger.error("appendTextToFile : Exception, ex=%s", SolBase.exToStr(e))
+            logger.error("append_text_tofile : Exception, ex=%s", SolBase.extostr(e))
             return -1
         finally:
             # Close if not None...
