@@ -36,7 +36,7 @@ class SysLogger(SysLogHandler):
     """
 
     def __init__(self, address="/dev/log", facility=SysLogHandler.LOG_LOCAL1, socktype=socket.SOCK_DGRAM,
-                 logCallback=None):
+                 log_callback=None):
         """
         Init
         :param address: tuple ('ip', port) or string "target"
@@ -45,24 +45,25 @@ class SysLogger(SysLogHandler):
         :type facility: int
         :param socktype: Type of socket
         :type socktype: int
-        :param logCallback: Callback for unit test
+        :param log_callback: Callback for unit test
         """
 
         # Store
-        self._logCallback = logCallback
+        self._log_callback = log_callback
 
         # Base call
         SysLogHandler.__init__(self, address, facility, socktype)
 
-    def notifyLog(self, msg):
+    def notify_log(self, msg):
         """
         Notify log to callback if set (unittest purpose)
         :param msg: Log message
         :type msg: unicode,str
         """
+        # noinspection PyBroadException
         try:
-            if self._logCallback:
-                self._logCallback(msg)
+            if self._log_callback:
+                self._log_callback(msg)
         except:
             pass
 
@@ -74,26 +75,27 @@ class SysLogger(SysLogHandler):
         """
 
         # Write
+        # noinspection PyBroadException
         try:
             # Format
             msg = self.format(record) + '\000'
 
             # Get component name
-            cn = SolBase.getCompoName()
+            cn = SolBase.get_compo_name()
 
             # We append the machine+component name at the beginning
             if isinstance(msg, unicode):
-                msg = u"{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)
+                msg = u"{0} | {1} | {2}".format(SolBase.get_machine_name(), cn, msg)
                 msg = msg.encode('utf-8')
             else:
-                msg = "{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)
+                msg = "{0} | {1} | {2}".format(SolBase.get_machine_name(), cn, msg)
 
             # Add priority + facility (int)
             priority = '<%d>' % self.encodePriority(self.facility, self.mapPriority(record.levelname))
             msg = priority + cn + ": " + msg
 
             # Notify
-            self.notifyLog(msg)
+            self.notify_log(msg)
 
             # Send to socket
             if self.unixsocket:
