@@ -90,18 +90,18 @@ class Daemon(object):
         self._changeDir = change_dir
         self._onStartExitZero = on_start_exit_zero
 
-        logger.info("_pidfile=%s", self._pidfile)
-        logger.info("_maxOpenFiles=%s", self._maxOpenFiles)
-        logger.info("_timeout_ms=%s", self._timeout_ms)
+        logger.debug("_pidfile=%s", self._pidfile)
+        logger.debug("_maxOpenFiles=%s", self._maxOpenFiles)
+        logger.debug("_timeout_ms=%s", self._timeout_ms)
 
-        logger.info("_stdin=%s", self._stdin)
-        logger.info("_stdout=%s", self._stdout)
-        logger.info("_stderr=%s", self._stderr)
+        logger.debug("_stdin=%s", self._stdin)
+        logger.debug("_stdout=%s", self._stdout)
+        logger.debug("_stderr=%s", self._stderr)
 
-        logger.info("_onStartExitZero=%s", self._onStartExitZero)
-        logger.info("_changeDir=%s", self._changeDir)
+        logger.debug("_onStartExitZero=%s", self._onStartExitZero)
+        logger.debug("_changeDir=%s", self._changeDir)
 
-        logger.info("vars=%s", self.vars)
+        logger.debug("vars=%s", self.vars)
 
         # Check
         if not pidfile:
@@ -127,23 +127,23 @@ class Daemon(object):
         se = None
 
         # Flush
-        logger.info("flushing")
+        logger.debug("flushing")
         sys.stdout.flush()
         sys.stderr.flush()
 
         # Open new std
         try:
-            logger.info("opening new ones")
+            logger.debug("opening new ones")
             si = open(self._stdin, "r")
             so = open(self._stdout, "a+")
             se = open(self._stderr, "a+", 0)
 
             # Dup std
-            logger.info("dup2 (expecting log loss now)")
+            logger.debug("dup2 (expecting log loss now)")
             os.dup2(si.fileno(), sys.stdin.fileno())
             os.dup2(so.fileno(), sys.stdout.fileno())
             os.dup2(se.fileno(), sys.stderr.fileno())
-            logger.info("dup2 done")
+            logger.debug("dup2 done")
 
             # Ok
             return
@@ -166,18 +166,18 @@ class Daemon(object):
 
         try:
             # Flush
-            logger.info("flushing")
+            logger.debug("flushing")
             sys.stdout.flush()
             sys.stderr.flush()
 
             # Open new std
-            logger.info("opening new ones")
+            logger.debug("opening new ones")
             si = open(self._stdin, "r")
             so = open(self._stdout, "a+")
             se = open(self._stderr, "a+", 0)
 
             # Dup std
-            logger.info("assigning (expecting log loss now)")
+            logger.debug("assigning (expecting log loss now)")
             sys.stdin = si
             sys.stdout = so
             sys.stderr = se
@@ -196,18 +196,18 @@ class Daemon(object):
         Set limits
         """
 
-        logger.info("Setting max open file=%s", self._maxOpenFiles)
+        logger.debug("Setting max open file=%s", self._maxOpenFiles)
         try:
             # Get
             self._softLimit, self._hardLimit = resource.getrlimit(resource.RLIMIT_NOFILE)
-            logger.info("rlimit before : soft=%s, hard=%s", self._softLimit, self._hardLimit)
+            logger.debug("rlimit before : soft=%s, hard=%s", self._softLimit, self._hardLimit)
 
             # Update
             resource.setrlimit(resource.RLIMIT_NOFILE, (self._maxOpenFiles, self._maxOpenFiles))
 
             # Get
             self._softLimit, self._hardLimit = resource.getrlimit(resource.RLIMIT_NOFILE)
-            logger.info("rlimit after, soft=%s, hard=%s", self._softLimit, self._hardLimit)
+            logger.debug("rlimit after, soft=%s, hard=%s", self._softLimit, self._hardLimit)
 
         except Exception as ex:
             # Get
@@ -226,13 +226,13 @@ class Daemon(object):
         daemonize us
         """
 
-        logger.info("Entering, pid=%s", os.getpid())
+        logger.debug("Entering, pid=%s", os.getpid())
 
         # Limit
         self._set_limits()
 
         # Fork1
-        logger.info("fork1, %s", SolBase.get_current_pid_as_string())
+        logger.debug("fork1, %s", SolBase.get_current_pid_as_string())
         try:
             pid = gevent.fork()
             if pid > 0:
@@ -242,21 +242,21 @@ class Daemon(object):
             logger.error("fork1 failed, exit(1) now : errno=%s, err=%s, ex=%s", ex.errno, ex.strerror,
                          SolBase.extostr(ex))
             sys.exit(1)
-        logger.info("fork1 done, %s", SolBase.get_current_pid_as_string())
+        logger.debug("fork1 done, %s", SolBase.get_current_pid_as_string())
 
         # Diverge from parent
         if self._changeDir:
-            logger.info("chdir now")
+            logger.debug("chdir now")
             os.chdir("/")
 
         # Set stuff
-        logger.info("setsid and umask")
+        logger.debug("setsid and umask")
         # noinspection PyArgumentList
         os.setsid()
         os.umask(0)
 
         # Fork2
-        logger.info("fork2, %s", SolBase.get_current_pid_as_string())
+        logger.debug("fork2, %s", SolBase.get_current_pid_as_string())
         try:
             pid = gevent.fork()
             if pid > 0:
@@ -266,13 +266,13 @@ class Daemon(object):
             logger.error("fork2 failed, exit(2) now : errno=%s, err=%s, ex=%s", ex.errno, ex.strerror,
                          SolBase.extostr(ex))
             sys.exit(2)
-        logger.info("fork2 done, %s", SolBase.get_current_pid_as_string())
+        logger.debug("fork2 done, %s", SolBase.get_current_pid_as_string())
 
         # Redirect std
         self._redirect_all_std()
 
         # Go
-        logger.info("initializing _pidfile=%s", self._pidfile)
+        logger.debug("initializing _pidfile=%s", self._pidfile)
 
         # Register the method called at exit
         atexit.register(self._remove_pid_file)
@@ -285,25 +285,25 @@ class Daemon(object):
             f.close()
 
         except IOError as ex:
-            logger.info("pid file initialization failed, going exit(3), ex=%s", SolBase.extostr(ex))
+            logger.debug("pid file initialization failed, going exit(3), ex=%s", SolBase.extostr(ex))
             sys.exit(3)
 
             # Ok
-        logger.info("pid file set")
+        logger.debug("pid file set")
 
         # Finish
-        logger.info("registering gevent signal handler : SIGUSR1")
+        logger.debug("registering gevent signal handler : SIGUSR1")
         gevent.signal(signal.SIGUSR1, self._on_reload)
-        logger.info("registering gevent signal handler : SIGUSR2")
+        logger.debug("registering gevent signal handler : SIGUSR2")
         gevent.signal(signal.SIGUSR2, self._on_status)
-        logger.info("registering gevent signal handler : SIGTERM")
+        logger.debug("registering gevent signal handler : SIGTERM")
         gevent.signal(signal.SIGTERM, self._exit_handler)
 
-        logger.info("registering gevent signal handler : done")
+        logger.debug("registering gevent signal handler : done")
 
         # Fatality
         SolBase.voodoo_init()
-        logger.info("process started, pid=%s, pidfile=%s", os.getpid(), self._pidfile)
+        logger.debug("process started, pid=%s, pidfile=%s", os.getpid(), self._pidfile)
 
     def _remove_pid_file(self):
         """
@@ -323,10 +323,10 @@ class Daemon(object):
         """
         if group:
             os.setgid(grp.getgrnam(group).gr_gid)
-            logger.info("group set=%s", group)
+            logger.debug("group set=%s", group)
         if user:
             os.setuid(pwd.getpwnam(user).pw_uid)
-            logger.info("user set=%s", user)
+            logger.debug("user set=%s", user)
 
     def _get_running_pid(self):
         """
@@ -386,7 +386,7 @@ class Daemon(object):
         finally:
             pass
 
-        logger.info("exiting Daemon with exit(0)")
+        logger.debug("exiting Daemon with exit(0)")
         sys.exit(0)
 
     #===============================================
@@ -410,7 +410,7 @@ class Daemon(object):
         # - Other : 4 => NOT TESTED
         """
         # Check for a pidfile to see if the Daemon already runs
-        logger.info("entering")
+        logger.debug("entering")
         pid = self._get_running_pid()
 
         # Pid ?
@@ -424,9 +424,9 @@ class Daemon(object):
                 sys.exit(1)
             except OSError as err:
                 if err.errno == errno.ESRCH:
-                    logger.info("Found pidfile but SIGUSR2 failed, pid=%s, pidfile=%s", pid, self._pidfile)
+                    logger.info("Found pidfile but SIGUSR2 failed, rm on file, pid=%s, pidfile=%s", pid, self._pidfile)
                     if os.path.exists(self._pidfile):
-                        logger.info("Removing pidfile")
+                        logger.debug("Removing pidfile")
                         self._remove_pid_file()
 
         # Ok start now
@@ -442,10 +442,10 @@ class Daemon(object):
 
         # Exit
         if self._onStartExitZero is True:
-            logger.info("exiting WITH exit(0) due to _onStartExitZero==True")
+            logger.debug("exiting WITH exit(0) due to _onStartExitZero==True")
             sys.exit(0)
         else:
-            logger.info("exiting WITHOUT exit(0)")
+            logger.debug("exiting WITHOUT exit(0)")
 
     def _daemon_stop(self):
         """
@@ -458,7 +458,7 @@ class Daemon(object):
 
         """
 
-        logger.info("entering")
+        logger.debug("entering")
 
         # Get the pid from the pidfile
         pid = self._get_running_pid()
@@ -467,7 +467,7 @@ class Daemon(object):
             return
 
         # Stop it
-        logger.info("sending SIGTERM, pid=%s, pidFile=%s", pid, self._pidfile)
+        logger.debug("sending SIGTERM, pid=%s, pidFile=%s", pid, self._pidfile)
         try:
             os.kill(pid, signal.SIGTERM)
         except OSError as ex:
@@ -480,11 +480,11 @@ class Daemon(object):
             sys.exit(1)
         finally:
             if os.path.exists(self._pidfile):
-                logger.info("Removing pidFile=%s", self._pidfile)
+                logger.debug("Removing pidFile=%s", self._pidfile)
                 self._remove_pid_file()
 
         # Ok
-        logger.info("SIGTERM sent")
+        logger.debug("SIGTERM sent")
         ms_start = SolBase.mscurrent()
 
         # Validate
@@ -568,7 +568,7 @@ class Daemon(object):
         :return ArgumentParser
         :rtype ArgumentParser
         """
-        logger.info("Entering")
+        logger.debug("Entering")
 
         # Create an argument parser
         arg_parser = argparse.ArgumentParser(description='SolBase.Daemon', add_help=True)
@@ -675,7 +675,7 @@ class Daemon(object):
             action="store",
             help="Daemon action to perform (start|stop|status|reload) [required]"
         )
-        logger.info("Done")
+        logger.debug("Done")
         return arg_parser
 
     @classmethod
@@ -689,7 +689,7 @@ class Daemon(object):
         :rtype dict
         """
 
-        logger.info("Entering")
+        logger.debug("Entering")
 
         # Check argv
         if not isinstance(argv, (tuple, list)):
@@ -700,7 +700,7 @@ class Daemon(object):
 
         # Flush
         d = vars(local_args)
-        logger.info("Having vars=%s", d)
+        logger.debug("Having vars=%s", d)
 
         return d
 
@@ -733,7 +733,7 @@ class Daemon(object):
         :rtype Daemon
         """
 
-        logger.info("Entering, argv=%s, kwargs=%s", argv, kwargs)
+        logger.debug("Entering, argv=%s, kwargs=%s", argv, kwargs)
 
         try:
             # Parse
@@ -753,13 +753,13 @@ class Daemon(object):
             timeout_ms = vars_hsh["timeoutms"]
 
             # Allocate now
-            logger.info("Allocating Daemon")
+            logger.debug("Allocating Daemon")
             di = cls.get_daemon_instance()
 
             # Store vars
             di.vars = vars_hsh
 
-            logger.info("Internal initialization, class=%s", SolBase.get_classname(di))
+            logger.debug("Internal initialization, class=%s", SolBase.get_classname(di))
             di._internal_init(
                 pidfile=pidfile,
                 stdin=stdin, stdout=stdout, stderr=stderr,
@@ -769,7 +769,7 @@ class Daemon(object):
                 timeout_ms=timeout_ms
             )
 
-            logger.info("action=%s, user=%s, group=%s", action, user, group)
+            logger.debug("action=%s, user=%s, group=%s", action, user, group)
 
             if action == "start":
                 di._daemon_start(user, group)
@@ -789,7 +789,7 @@ class Daemon(object):
                 sys.exit(2)
 
             # Done
-            logger.info("Done")
+            logger.debug("Done")
             return di
         except Exception as ex:
             logger.error("Exception, ex=%s", SolBase.extostr(ex))
@@ -808,7 +808,7 @@ if __name__ == "__main__":
         # Go
         cur_path = sys.path
         for s in cur_path:
-            logger.info("__main__ : Starting, path=%s", s)
+            logger.debug("__main__ : Starting, path=%s", s)
 
         # Run
         Daemon.main_helper(sys.argv, {})
@@ -817,4 +817,4 @@ if __name__ == "__main__":
         logger.error("__main__ : Exception, exiting -1, ex=%s", SolBase.extostr(e))
         sys.exit(-1)
     finally:
-        logger.info("__main__ : Exiting now")
+        logger.debug("__main__ : Exiting now")
